

.. image:: https://badge.fury.io/py/cylinder_fitting.svg
      :target: https://badge.fury.io/py/cylinder_fitting

Fit a set of 3D points to a cylinder surface.

Usage example:

.. code-block:: python

      from cylinder_fitting import fit
      w_fit, C_fit, r_fit, fit_err = fit(data)

For a detailed example, see the `unit test <https://github.com/xingjiepan/cylinder_fitting/blob/master/tests/test_fitting.py>`_.
